@@ -139,7 +139,10 @@ class PS4000(_PicoscopeBase):
             self.lib = LoadLibraryDarwin("lib" + self.LIBNAME + ".dylib")
         else:
             from ctypes import windll
-            self.lib = windll.LoadLibrary(str(self.LIBNAME + ".dll"))
+            from ctypes.util import find_library
+            self.lib = windll.LoadLibrary(
+                find_library(str(self.LIBNAME + ".dll"))
+            )
 
         super(PS4000, self).__init__(serialNumber, connect)
         # check to see which model we have and use special functions if needed
